@@ -34,6 +34,7 @@
 #include <QFileInfo>
 #include <QMessageBox>
 #include <QPointer>
+#include <QtMath>
 
 namespace Caneda
 {
@@ -42,7 +43,7 @@ namespace Caneda
         IDocument *document;
         QList<IView*> views;
 
-        DocumentData() { document = 0; }
+        DocumentData() { document = nullptr; }
     };
 
     //! \brief Constructor.
@@ -61,7 +62,7 @@ namespace Caneda
     //! \copydoc MainWindow::instance()
     DocumentViewManager* DocumentViewManager::instance()
     {
-        static DocumentViewManager* instance = 0;
+        static DocumentViewManager* instance = nullptr;
         if (!instance) {
             instance = new DocumentViewManager();
         }
@@ -73,14 +74,13 @@ namespace Caneda
         IView *newView = document->createView();
         if (!newView) {
             qWarning() << Q_FUNC_INFO << "View creation failed";
-            return 0;
+            return nullptr;
         }
 
         DocumentData *data = documentDataForDocument(document);
         data->views.insert(0, newView);
 
-        connect(newView, SIGNAL(focussedIn(IView*)), this,
-                SLOT(onViewFocussedIn(IView*)));
+        connect(newView, &IView::focussedIn, this, &DocumentViewManager::onViewFocussedIn);
 
         emit changed();
 
@@ -98,7 +98,7 @@ namespace Caneda
     {
         DocumentData *data = documentDataForDocument(document);
 
-        IView *view = 0;
+        IView *view = nullptr;
 
         // If the document was just opened, a view must be created
         if (data->views.isEmpty()) {
@@ -116,7 +116,7 @@ namespace Caneda
     void DocumentViewManager::newDocument(IContext *context)
     {
         StateHandler *handler = StateHandler::instance();
-        handler->slotSetNormalAction();
+        handler->setNormalAction();
 
         IDocument *document = context->newDocument();
         if (!document) {
@@ -135,7 +135,7 @@ namespace Caneda
     bool DocumentViewManager::openFile(const QString &fileName)
     {
         StateHandler *handler = StateHandler::instance();
-        handler->slotSetNormalAction();
+        handler->setNormalAction();
 
         if(fileName.isEmpty()) {
             return false;
@@ -150,7 +150,7 @@ namespace Caneda
         // file contents.
         if(data) {
             // Grab the first view of the document
-            IView *view = 0;
+            IView *view = nullptr;
             if (!data->views.isEmpty()) {
                 view = viewsForDocument(data->document).first();
             }
@@ -187,12 +187,13 @@ namespace Caneda
             highlightViewForDocument(data->document);
         }
 
-        return data != 0;
+        return data != nullptr;
     }
 
+    //! \brief Prompt the user to save the modified documents.
     bool DocumentViewManager::saveDocuments(const QList<IDocument*> &documents)
     {
-        // First collect only the modified documents and prompt for save.
+        // Collect the modified documents and prompt for save.
         QList<IDocument*> modifiedDocuments;
         foreach (IDocument *document, documents) {
             if (document->isModified()) {
@@ -204,45 +205,15 @@ namespace Caneda
             return true;
         }
 
-        QPointer<SaveDocumentsDialog> dialog(new SaveDocumentsDialog(modifiedDocuments));
-        dialog->exec();
+        SaveDocumentsDialog *dialog = new SaveDocumentsDialog(modifiedDocuments);
+        int result = dialog->exec();
+        delete dialog;
 
-        int result = dialog->result();
-
-        if (result == SaveDocumentsDialog::DoNotSave) {
+        if (result == QDialog::Accepted) {
             return true;
         }
-        else if (result == SaveDocumentsDialog::Abort) {
-            return false;
-        }
-        else {
-            QList<QPair<IDocument*, QString> > newFilePaths = dialog->newFilePaths();
-            QList<QPair<IDocument*, QString> >::iterator it;
 
-            bool failedInBetween = false;
-
-            for (it = newFilePaths.begin(); it != newFilePaths.end(); ++it) {
-                IDocument *document = it->first;
-                const QString newFileName = it->second;
-                QString oldFileName = document->fileName();
-
-                document->setFileName(newFileName);
-                if (!document->save()) {
-                    failedInBetween = true;
-                    document->setFileName(oldFileName);
-                }
-            }
-
-            if (failedInBetween) {
-                QMessageBox::critical(0, tr("File save error"),
-                        tr("Could not save some files"));
-                return false;
-            }
-        }
-
-        delete dialog.data();
-
-        return true;
+        return false;
     }
 
     bool DocumentViewManager::closeDocuments(const QList<IDocument*> &documents,
@@ -258,7 +229,7 @@ namespace Caneda
         foreach (IDocument *document, documents) {
             DocumentData *data = documentDataForDocument(document);
 
-            Q_ASSERT(data != 0);
+            Q_ASSERT(data != nullptr);
 
             bool closedAllViews = true;
             foreach (IView *view, data->views) {
@@ -278,7 +249,7 @@ namespace Caneda
             m_documentDataList.removeAll(data);
 
             delete data->document;
-            data->document = 0;
+            data->document = nullptr;
 
             delete data;
             ++closedDocumentsCount;
@@ -295,8 +266,7 @@ namespace Caneda
     {
         QStringList nameFilters;
 
-        nameFilters << QObject::tr("Any File (*)")+" (*);;";
-        nameFilters << QObject::tr("Caneda project (*.xpro)")+" (*.xpro);;";
+        nameFilters << QObject::tr("Any File (*)");
 
         foreach (IContext *context, m_contexts) {
             nameFilters << context->fileNameFilters();
@@ -326,6 +296,10 @@ namespace Caneda
     bool DocumentViewManager::closeViewHelper(IView *view, bool askSaveIfModified,
             bool closeDocumentIfLastView)
     {
+        if(!view) {
+            return false;
+        }
+
         DocumentData *data = documentDataForDocument(view->document());
 
         if (data->document->isModified()) {
@@ -345,7 +319,6 @@ namespace Caneda
 
         emit changed();
 
-
         // Now if closeDocumentIfLastView is true and there are no more views
         // for the document, then just close the document too.
         if (closeDocumentIfLastView && data->views.isEmpty()) {
@@ -362,8 +335,6 @@ namespace Caneda
 
     void DocumentViewManager::replaceView(IView *oldView, IDocument *document)
     {
-        DocumentData *data = documentDataForDocument(document);
-
         IView *newView = createView(document);
         if (!newView) {
             return;
@@ -387,45 +358,19 @@ namespace Caneda
         if (view) {
             return view->document();
         }
-        return 0;
+        return nullptr;
     }
 
     IView* DocumentViewManager::currentView() const
     {
         Tab *tab = tabWidget()->currentTab();
         if (!tab) {
-            return 0;
+            return nullptr;
         }
 
         return tab->activeView();
     }
 
-    IDocument* DocumentViewManager::documentForFileName(const QString &fileName) const
-    {
-        DocumentData *data = documentDataForFileName(fileName);
-        if (data) {
-            return data->document;
-        }
-
-        return 0;
-    }
-
-    QList<IView*> DocumentViewManager::viewsForDocument(const IDocument *document) const
-    {
-        QList<DocumentData*>::const_iterator it = m_documentDataList.constBegin(),
-            end = m_documentDataList.constEnd();
-        for (; it != end; ++it) {
-            if ((*it)->document == document) {
-                return (*it)->views;
-            }
-        }
-
-        qDebug() << Q_FUNC_INFO << "Document " << (void*)document
-            << " is not in manager's document data list";
-
-        return QList<IView*>();
-    }
-
     QList<IDocument*> DocumentViewManager::documents() const
     {
         QList<IDocument*> documents;
@@ -438,6 +383,44 @@ namespace Caneda
         return documents;
     }
 
+    QList<IView*> DocumentViewManager::views() const
+    {
+        QList<IView*> views;
+        QList<Tab*> tabs = tabWidget()->tabs();
+
+        foreach(Tab *tab, tabs) {
+            views << tab->views();
+        }
+
+        return views;
+    }
+
+    IDocument* DocumentViewManager::documentForFileName(const QString &fileName) const
+    {
+        DocumentData *data = documentDataForFileName(fileName);
+        if (data) {
+            return data->document;
+        }
+
+        return nullptr;
+    }
+
+    QList<IView*> DocumentViewManager::viewsForDocument(const IDocument *document) const
+    {
+        QList<DocumentData*>::const_iterator it = m_documentDataList.constBegin(),
+            end = m_documentDataList.constEnd();
+        for (; it != end; ++it) {
+            if ((*it)->document == document) {
+                return (*it)->views;
+            }
+        }
+
+        qDebug() << Q_FUNC_INFO << "Document " << document->fileName()
+            << " is not in manager's document data list";
+
+        return QList<IView*>();
+    }
+
     void DocumentViewManager::updateSettingsChanges()
     {
         QList<DocumentData*>::iterator it = m_documentDataList.begin(),
@@ -486,6 +469,18 @@ namespace Caneda
         updateRecentFilesActionList();
     }
 
+    /*!
+     * \brief Clears the list of recently opened documents.
+     *
+     * \sa addFileToRecentFiles(), updateRecentFilesActionList()
+     */
+    void DocumentViewManager::clearRecentFiles()
+    {
+        Settings *settings = Settings::instance();
+        settings->setCurrentValue("gui/recentFiles", QStringList());
+        updateRecentFilesActionList();
+    }
+
     /*!
      * \brief Updates recent files list
      *
@@ -560,7 +555,7 @@ namespace Caneda
     DocumentData* DocumentViewManager::documentDataForFileName(const QString &fileName) const
     {
         if (fileName.isEmpty()) {
-            return 0;
+            return nullptr;
         }
 
         QList<DocumentData*>::const_iterator it = m_documentDataList.constBegin(),
@@ -572,7 +567,7 @@ namespace Caneda
             }
         }
 
-        return 0;
+        return nullptr;
     }
 
     DocumentData* DocumentViewManager::documentDataForDocument(IDocument *document) const
@@ -586,17 +581,15 @@ namespace Caneda
             }
         }
 
-        return 0;
+        return nullptr;
     }
 
     void DocumentViewManager::setupContexts()
     {
         m_contexts << SchematicContext::instance();
         m_contexts << SymbolContext::instance();
-        m_contexts << LayoutContext::instance();
         m_contexts << SimulationContext::instance();
         m_contexts << TextContext::instance();
-        m_contexts << WebContext::instance();
     }
 
     TabWidget* DocumentViewManager::tabWidget() const
