@@ -22,11 +22,11 @@
 
 #include "idocument.h"
 #include "library.h"
+#include "quickinsert.h"
 #include "settings.h"
-#include "sidebarbrowser.h"
-#include "sidebarsimulationbrowser.h"
+#include "sidebarchartsbrowser.h"
+#include "sidebaritemsbrowser.h"
 #include "sidebartextbrowser.h"
-#include "sidebarwebbrowser.h"
 #include "statehandler.h"
 
 #include <QDebug>
@@ -43,6 +43,72 @@ namespace Caneda
     {
     }
 
+    /*!
+     * \brief Indicates if a particular file extension is managed by this
+     * context.
+     *
+     * This method indicates if a particular file extension is managed by this
+     * context. This allows to find what context is in charge of a particular
+     * file type.
+     */
+    bool IContext::canOpen(const QFileInfo &info) const
+    {
+        foreach (const QString &suffix, supportedSuffixes()) {
+            if (info.suffix() == suffix) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
+    /*!
+     * \brief Returns the default suffix of the current context type.
+     *
+     * This method returns the default suffix of this context to be used in
+     * any dialog required. It always returns the first suffix of the
+     * supportedSuffixes method.
+     *
+     * \sa supportedSuffixes()
+     */
+    QString IContext::defaultSuffix() const
+    {
+        return supportedSuffixes().first();
+    }
+
+    /*!
+     * \fn IContext::fileNameFilters()
+     *
+     * \brief Returns the filename extensions or filters available for this
+     * context.
+     *
+     * Filename filters are used in open/save dialogs to allow the user to
+     * filter the files displayed and ease the selection of the wanted file. In
+     * this way, for example, if opening a schematic document the dialog should
+     * display only schematic files. The method fileNameFilters() is used to
+     * know what extensions correspond to that particular type of context.
+     */
+
+    /*!
+     * \fn IContext::supportedSuffixes()
+     *
+     * \brief Returns the filename extensions available for this context.
+     *
+     * \sa defaultSuffix(), fileNameFilters()
+     */
+
+    /*!
+     * \fn IContext::newDocument()
+     *
+     * \brief Create a new document of the current context type.
+     */
+
+    /*!
+     * \fn IContext::open()
+     *
+     * \brief Open a document of the current context type.
+     */
+
     /*!
      * \fn IContext::toolBar()
      *
@@ -79,19 +145,6 @@ namespace Caneda
      * \sa toolBar(), updateSideBar()
      */
 
-    /*!
-     * \fn IContext::sideBarTitle()
-     *
-     * \brief Returns the sideBarWidget title to this context.
-     *
-     * SideBarWidgets are context sensitive, containing only those items and
-     * tools relative to the current context as components, painting tools,
-     * code snippets, etc. This method returns the sideBar title corresponding
-     * to this context, allowing to update the title of the sidebarDockWidget.
-     *
-     * \sa sideBarWidget(), TabWidget::updateTabContext()
-     */
-
     /*!
      * \fn IContext::updateSideBar()
      *
@@ -107,155 +160,18 @@ namespace Caneda
      */
 
     /*!
-     * \fn IContext::canOpen()
+     * \fn IContext::quickInsert()
      *
-     * \brief Indicates if a particular file extension is managed by this
-     * context.
+     * \brief Opens an insert dialog for items available in this context.
      *
-     * This method indicates if a particular file extension is managed by this
-     * context. This allows to find what context is in charge of a particular
-     * file type.
+     * Insert items are context sensitive, containing only those items relative
+     * to the current context as components, painting tools, code snippets,
+     * etc. This method allows for an external event to request an insert items
+     * dialog.
+     *
+     * \sa sideBarWidget()
      */
 
-    /*!
-     * \fn IContext::fileNameFilters()
-     *
-     * \brief Returns the filename extensions or filters available for this
-     * context.
-     *
-     * Filename filters are used in open/save dialogs to allow the user to
-     * filter the files displayed and ease the selection of the wanted file. In
-     * this way, for example, if opening a schematic document the dialog should
-     * display only schematic files. The method fileNameFilters() is used to
-     * know what extensions correspond to that particular type of context.
-     */
-
-    /*!
-     * \fn IContext::defaultSuffix()
-     *
-     * \brief Returns the default suffix of the current content type.
-     */
-
-    /*!
-     * \fn IContext::newDocument()
-     *
-     * \brief Create a new document of the current context type.
-     */
-
-    /*!
-     * \fn IContext::open()
-     *
-     * \brief Open a document of the current context type.
-     */
-
-    /*************************************************************************
-     *                          Layout Context                               *
-     *************************************************************************/
-    //! \brief Constructor.
-    LayoutContext::LayoutContext(QObject *parent) : IContext(parent)
-    {
-        // We create the sidebar corresponding to this context
-        StateHandler *handler = StateHandler::instance();
-        m_sidebarBrowser = new SidebarBrowser();
-        connect(m_sidebarBrowser, SIGNAL(itemClicked(const QString&, const QString&)), handler,
-                SLOT(slotSidebarItemClicked(const QString&, const QString&)));
-
-        Settings *settings = Settings::instance();
-
-        QPixmap layer(20,20);
-
-        QList<QPair<QString, QPixmap> > layerItems;
-        layer.fill(settings->currentValue("gui/layout/metal1").value<QColor>());
-        layerItems << qMakePair(QObject::tr("Metal 1"), layer);
-        layer.fill(settings->currentValue("gui/layout/metal2").value<QColor>());
-        layerItems << qMakePair(QObject::tr("Metal 2"), layer);
-        layer.fill(settings->currentValue("gui/layout/poly1").value<QColor>());
-        layerItems << qMakePair(QObject::tr("Poly 1"), layer);
-        layer.fill(settings->currentValue("gui/layout/poly2").value<QColor>());
-        layerItems << qMakePair(QObject::tr("Poly 2"), layer);
-        layer.fill(settings->currentValue("gui/layout/active").value<QColor>());
-        layerItems << qMakePair(QObject::tr("Active"), layer);
-        layer.fill(settings->currentValue("gui/layout/contact").value<QColor>());
-        layerItems << qMakePair(QObject::tr("Contact"), layer);
-        layer.fill(settings->currentValue("gui/layout/nwell").value<QColor>());
-        layerItems << qMakePair(QObject::tr("N Well"), layer);
-        layer.fill(settings->currentValue("gui/layout/pwell").value<QColor>());
-        layerItems << qMakePair(QObject::tr("P Well"), layer);
-
-        QList<QPair<QString, QPixmap> > paintingItems;
-        paintingItems << qMakePair(QObject::tr("Arrow"),
-                QPixmap(Caneda::bitmapDirectory() + "arrow.svg"));
-        paintingItems << qMakePair(QObject::tr("Ellipse"),
-                QPixmap(Caneda::bitmapDirectory() + "ellipse.svg"));
-        paintingItems << qMakePair(QObject::tr("Elliptic Arc"),
-                QPixmap(Caneda::bitmapDirectory() + "ellipsearc.svg"));
-        paintingItems << qMakePair(QObject::tr("Line"),
-                QPixmap(Caneda::bitmapDirectory() + "line.svg"));
-        paintingItems << qMakePair(QObject::tr("Rectangle"),
-                QPixmap(Caneda::bitmapDirectory() + "rectangle.svg"));
-        paintingItems << qMakePair(QObject::tr("Text"),
-                QPixmap(Caneda::bitmapDirectory() + "text.svg"));
-
-        m_sidebarBrowser->plugItems(layerItems, QObject::tr("Layout Tools"));
-        m_sidebarBrowser->plugItems(paintingItems, QObject::tr("Paint Tools"));
-    }
-
-    //! \copydoc MainWindow::instance()
-    LayoutContext* LayoutContext::instance()
-    {
-        static LayoutContext *context = 0;
-        if (!context) {
-            context = new LayoutContext();
-        }
-        return context;
-    }
-
-    QWidget* LayoutContext::sideBarWidget()
-    {
-        return m_sidebarBrowser;
-    }
-
-    bool LayoutContext::canOpen(const QFileInfo &info) const
-    {
-        QStringList supportedSuffixes;
-        supportedSuffixes << "xlay";
-
-        foreach (const QString &suffix, supportedSuffixes) {
-            if (suffix == info.suffix()) {
-                return true;
-            }
-        }
-
-        return false;
-    }
-
-    QStringList LayoutContext::fileNameFilters() const
-    {
-        QStringList nameFilters;
-        nameFilters << QObject::tr("Layout-xml (*.xlay)")+" (*.xlay);;";
-
-        return nameFilters;
-    }
-
-    IDocument* LayoutContext::newDocument()
-    {
-        return new LayoutDocument;
-    }
-
-    IDocument* LayoutContext::open(const QString &fileName,
-            QString *errorMessage)
-    {
-        LayoutDocument *document = new LayoutDocument();
-        document->setFileName(fileName);
-
-        if (!document->load(errorMessage)) {
-            delete document;
-            document = 0;
-        }
-
-        return document;
-    }
-
     /*************************************************************************
      *                         Schematic Context                             *
      *************************************************************************/
@@ -263,15 +179,15 @@ namespace Caneda
     SchematicContext::SchematicContext(QObject *parent) : IContext(parent)
     {
         StateHandler *handler = StateHandler::instance();
-        m_sidebarBrowser = new SidebarBrowser();
-        connect(m_sidebarBrowser, SIGNAL(itemClicked(const QString&, const QString&)), handler,
-                SLOT(slotSidebarItemClicked(const QString&, const QString&)));
+        m_sidebarItems = new SidebarItemsModel(this);
+        m_sidebarBrowser = new SidebarItemsBrowser(m_sidebarItems);
+
+        connect(m_sidebarBrowser, QOverload<const QString&, const QString&>::of(&SidebarItemsBrowser::itemClicked),
+                handler,          QOverload<const QString&, const QString&>::of(&StateHandler::insertItem));
 
         // Load schematic libraries
         LibraryManager *libraryManager = LibraryManager::instance();
         if(libraryManager->loadLibraryTree()) {
-            // Plug the components root
-            m_sidebarBrowser->plugItem("Components", QPixmap(), "root");
 
             // Get the libraries list and sort them alphabetically
             QStringList libraries(libraryManager->librariesList());
@@ -279,7 +195,7 @@ namespace Caneda
 
             // Plug each library into the sidebar browser
             foreach(const QString library, libraries) {
-                m_sidebarBrowser->plugLibrary(library, "Components");
+                m_sidebarItems->plugLibrary(library, "Components");
                 qDebug() << "Loaded " + library + " library";
             }
 
@@ -293,66 +209,56 @@ namespace Caneda
 
         QList<QPair<QString, QPixmap> > miscellaneousItems;
         miscellaneousItems << qMakePair(QObject::tr("Ground"),
-                QPixmap(Caneda::bitmapDirectory() + "ground.svg"));
+                QPixmap(Caneda::imageDirectory() + "ground.svg"));
         miscellaneousItems << qMakePair(QObject::tr("Port Symbol"),
-                QPixmap(Caneda::bitmapDirectory() + "portsymbol.svg"));
-
-        m_sidebarBrowser->plugItems(miscellaneousItems, QObject::tr("Miscellaneous"));
+                QPixmap(Caneda::imageDirectory() + "portsymbol.svg"));
 
         QList<QPair<QString, QPixmap> > paintingItems;
         paintingItems << qMakePair(QObject::tr("Arrow"),
-                QPixmap(Caneda::bitmapDirectory() + "arrow.svg"));
+                QPixmap(Caneda::imageDirectory() + "arrow.svg"));
         paintingItems << qMakePair(QObject::tr("Ellipse"),
-                QPixmap(Caneda::bitmapDirectory() + "ellipse.svg"));
+                QPixmap(Caneda::imageDirectory() + "ellipse.svg"));
         paintingItems << qMakePair(QObject::tr("Elliptic Arc"),
-                QPixmap(Caneda::bitmapDirectory() + "ellipsearc.svg"));
+                QPixmap(Caneda::imageDirectory() + "ellipsearc.svg"));
         paintingItems << qMakePair(QObject::tr("Line"),
-                QPixmap(Caneda::bitmapDirectory() + "line.svg"));
+                QPixmap(Caneda::imageDirectory() + "line.svg"));
         paintingItems << qMakePair(QObject::tr("Rectangle"),
-                QPixmap(Caneda::bitmapDirectory() + "rectangle.svg"));
+                QPixmap(Caneda::imageDirectory() + "rectangle.svg"));
         paintingItems << qMakePair(QObject::tr("Text"),
-                QPixmap(Caneda::bitmapDirectory() + "text.svg"));
+                QPixmap(Caneda::imageDirectory() + "text.svg"));
 
-        m_sidebarBrowser->plugItems(paintingItems, QObject::tr("Paint Tools"));
+        m_sidebarItems->plugItems(miscellaneousItems, QObject::tr("Miscellaneous"));
+        m_sidebarItems->plugItems(paintingItems, QObject::tr("Paint Tools"));
     }
 
     //! \copydoc MainWindow::instance()
     SchematicContext* SchematicContext::instance()
     {
-        static SchematicContext *context = 0;
+        static SchematicContext *context = nullptr;
         if (!context) {
             context = new SchematicContext();
         }
         return context;
     }
 
-    QWidget* SchematicContext::sideBarWidget()
-    {
-        return m_sidebarBrowser;
-    }
-
-    bool SchematicContext::canOpen(const QFileInfo &info) const
-    {
-        QStringList supportedSuffixes;
-        supportedSuffixes << "xsch";
-
-        foreach (const QString &suffix, supportedSuffixes) {
-            if (suffix == info.suffix()) {
-                return true;
-            }
-        }
-
-        return false;
-    }
-
     QStringList SchematicContext::fileNameFilters() const
     {
         QStringList nameFilters;
-        nameFilters << QObject::tr("Schematic-xml (*.xsch)")+" (*.xsch);;";
+        nameFilters << QObject::tr("Schematic-xml (*.xsch)");
 
         return nameFilters;
     }
 
+    QStringList SchematicContext::supportedSuffixes() const
+    {
+        // List of supported suffixes. The first suffix is the default value
+        // provided by defaultSuffix() for all dialogs.
+        QStringList supportedSuffixes;
+        supportedSuffixes << "xsch";
+
+        return supportedSuffixes;
+    }
+
     IDocument* SchematicContext::newDocument()
     {
         return new SchematicDocument;
@@ -366,65 +272,67 @@ namespace Caneda
 
         if (!document->load(errorMessage)) {
             delete document;
-            document = 0;
+            document = nullptr;
         }
 
         return document;
     }
 
+    QWidget* SchematicContext::sideBarWidget()
+    {
+        return m_sidebarBrowser;
+    }
+
+    void SchematicContext::quickInsert()
+    {
+        StateHandler *handler = StateHandler::instance();
+        QuickInsert *quickInsert = new QuickInsert(m_sidebarItems);
+
+        connect(quickInsert, QOverload<const QString&, const QString&>::of(&QuickInsert::itemClicked),
+                handler,     QOverload<const QString&, const QString&>::of(&StateHandler::insertItem));
+
+        quickInsert->exec(QCursor::pos());
+
+        delete quickInsert;
+    }
+
     /*************************************************************************
      *                        Simulation Context                             *
      *************************************************************************/
     //! \brief Constructor.
     SimulationContext::SimulationContext(QObject *parent) : IContext(parent)
     {
-        m_sidebarBrowser = new SidebarSimulationBrowser();
+        m_sidebarBrowser = new SidebarChartsBrowser();
     }
 
     //! \copydoc MainWindow::instance()
     SimulationContext* SimulationContext::instance()
     {
-        static SimulationContext *context = 0;
+        static SimulationContext *context = nullptr;
         if (!context) {
             context = new SimulationContext();
         }
         return context;
     }
 
-    QWidget *SimulationContext::sideBarWidget()
-    {
-        return m_sidebarBrowser;
-    }
-
-    void SimulationContext::updateSideBar()
-    {
-        if(m_sidebarBrowser) {
-            m_sidebarBrowser->updateWaveformsList();
-        }
-    }
-
-    bool SimulationContext::canOpen(const QFileInfo &info) const
-    {
-        QStringList supportedSuffixes;
-        supportedSuffixes << "raw";
-
-        foreach (const QString &suffix, supportedSuffixes) {
-            if (suffix == info.suffix()) {
-                return true;
-            }
-        }
-
-        return false;
-    }
-
     QStringList SimulationContext::fileNameFilters() const
     {
         QStringList nameFilters;
-        nameFilters << QObject::tr("Raw waveform data (*.raw)")+" (*.raw);;";
+        nameFilters << QObject::tr("Raw waveform data (*.raw)");
 
         return nameFilters;
     }
 
+    QStringList SimulationContext::supportedSuffixes() const
+    {
+        // List of supported suffixes. The first suffix is the default value
+        // provided by defaultSuffix() for all dialogs.
+        QStringList supportedSuffixes;
+        supportedSuffixes << "raw";
+
+        return supportedSuffixes;
+    }
+
     IDocument* SimulationContext::newDocument()
     {
         return new SimulationDocument;
@@ -438,12 +346,24 @@ namespace Caneda
 
         if (!document->load(errorMessage)) {
             delete document;
-            document = 0;
+            document = nullptr;
         }
 
         return document;
     }
 
+    QWidget *SimulationContext::sideBarWidget()
+    {
+        return m_sidebarBrowser;
+    }
+
+    void SimulationContext::updateSideBar()
+    {
+        if(m_sidebarBrowser) {
+            m_sidebarBrowser->updateChartSeriesMap();
+        }
+    }
+
     /*************************************************************************
      *                          Symbol Context                               *
      *************************************************************************/
@@ -451,70 +371,62 @@ namespace Caneda
     SymbolContext::SymbolContext(QObject *parent) : IContext(parent)
     {
         StateHandler *handler = StateHandler::instance();
-        m_sidebarBrowser = new SidebarBrowser();
-        connect(m_sidebarBrowser, SIGNAL(itemClicked(const QString&, const QString&)), handler,
-                SLOT(slotSidebarItemClicked(const QString&, const QString&)));
+        m_sidebarItems = new SidebarItemsModel(this);
+        m_sidebarBrowser = new SidebarItemsBrowser(m_sidebarItems);
+
+        connect(m_sidebarBrowser, QOverload<const QString&, const QString&>::of(&SidebarItemsBrowser::itemClicked),
+                handler,          QOverload<const QString&, const QString&>::of(&StateHandler::insertItem));
 
         QList<QPair<QString, QPixmap> > miscellaneousItems;
         miscellaneousItems << qMakePair(QObject::tr("Port Symbol"),
-                QPixmap(Caneda::bitmapDirectory() + "portsymbol.svg"));
-
-        m_sidebarBrowser->plugItems(miscellaneousItems, QObject::tr("Miscellaneous"));
+                QPixmap(Caneda::imageDirectory() + "portsymbol.svg"));
 
         QList<QPair<QString, QPixmap> > paintingItems;
         paintingItems << qMakePair(QObject::tr("Arrow"),
-                QPixmap(Caneda::bitmapDirectory() + "arrow.svg"));
+                QPixmap(Caneda::imageDirectory() + "arrow.svg"));
         paintingItems << qMakePair(QObject::tr("Ellipse"),
-                QPixmap(Caneda::bitmapDirectory() + "ellipse.svg"));
+                QPixmap(Caneda::imageDirectory() + "ellipse.svg"));
         paintingItems << qMakePair(QObject::tr("Elliptic Arc"),
-                QPixmap(Caneda::bitmapDirectory() + "ellipsearc.svg"));
+                QPixmap(Caneda::imageDirectory() + "ellipsearc.svg"));
         paintingItems << qMakePair(QObject::tr("Line"),
-                QPixmap(Caneda::bitmapDirectory() + "line.svg"));
+                QPixmap(Caneda::imageDirectory() + "line.svg"));
         paintingItems << qMakePair(QObject::tr("Rectangle"),
-                QPixmap(Caneda::bitmapDirectory() + "rectangle.svg"));
+                QPixmap(Caneda::imageDirectory() + "rectangle.svg"));
         paintingItems << qMakePair(QObject::tr("Text"),
-                QPixmap(Caneda::bitmapDirectory() + "text.svg"));
+                QPixmap(Caneda::imageDirectory() + "text.svg"));
 
-        m_sidebarBrowser->plugItems(paintingItems, QObject::tr("Paint Tools"));
+        m_sidebarItems->plugItems(miscellaneousItems, QObject::tr("Miscellaneous"));
+        m_sidebarItems->plugItems(paintingItems, QObject::tr("Paint Tools"));
     }
 
     //! \copydoc MainWindow::instance()
     SymbolContext* SymbolContext::instance()
     {
-        static SymbolContext *context = 0;
+        static SymbolContext *context = nullptr;
         if (!context) {
             context = new SymbolContext();
         }
         return context;
     }
 
-    QWidget* SymbolContext::sideBarWidget()
-    {
-        return m_sidebarBrowser;
-    }
-
-    bool SymbolContext::canOpen(const QFileInfo &info) const
-    {
-        QStringList supportedSuffixes;
-        supportedSuffixes << "xsym";
-
-        foreach (const QString &suffix, supportedSuffixes) {
-            if (suffix == info.suffix()) {
-                return true;
-            }
-        }
-
-        return false;
-    }
-
     QStringList SymbolContext::fileNameFilters() const
     {
         QStringList nameFilters;
-        nameFilters << QObject::tr("Symbol-xml (*.xsym)")+" (*.xsym);;";
+        nameFilters << QObject::tr("Symbol-xml (*.xsym)");
 
         return nameFilters;
     }
 
+    QStringList SymbolContext::supportedSuffixes() const
+    {
+        // List of supported suffixes. The first suffix is the default value
+        // provided by defaultSuffix() for all dialogs.
+        QStringList supportedSuffixes;
+        supportedSuffixes << "xsym";
+
+        return supportedSuffixes;
+    }
+
     IDocument* SymbolContext::newDocument()
     {
         return new SymbolDocument;
@@ -528,12 +440,30 @@ namespace Caneda
 
         if (!document->load(errorMessage)) {
             delete document;
-            document = 0;
+            document = nullptr;
         }
 
         return document;
     }
 
+    QWidget* SymbolContext::sideBarWidget()
+    {
+        return m_sidebarBrowser;
+    }
+
+    void SymbolContext::quickInsert()
+    {
+        StateHandler *handler = StateHandler::instance();
+        QuickInsert *quickInsert = new QuickInsert(m_sidebarItems);
+
+        connect(quickInsert, QOverload<const QString&, const QString&>::of(&QuickInsert::itemClicked),
+                handler,     QOverload<const QString&, const QString&>::of(&StateHandler::insertItem));
+
+        quickInsert->exec(QCursor::pos());
+
+        delete quickInsert;
+    }
+
     /*************************************************************************
      *                           Text Context                                *
      *************************************************************************/
@@ -546,22 +476,28 @@ namespace Caneda
     //! \copydoc MainWindow::instance()
     TextContext* TextContext::instance()
     {
-        static TextContext *instance = 0;
+        static TextContext *instance = nullptr;
         if (!instance) {
             instance = new TextContext();
         }
         return instance;
     }
 
-    QWidget* TextContext::sideBarWidget()
+    QStringList TextContext::fileNameFilters() const
     {
-        return m_sidebarTextBrowser;
+        QStringList nameFilters;
+        nameFilters << QObject::tr("Spice netlist (*.spc *.sp *.net *.cir)");
+        nameFilters << QObject::tr("HDL source (*.vhdl *.vhd *.v)");
+        nameFilters << QObject::tr("Text file (*.txt)");
+
+        return nameFilters;
     }
 
-    bool TextContext::canOpen(const QFileInfo& info) const
+    QStringList TextContext::supportedSuffixes() const
     {
+        // List of supported suffixes. The first suffix is the default value
+        // provided by defaultSuffix() for all dialogs.
         QStringList supportedSuffixes;
-        supportedSuffixes << "";
         supportedSuffixes << "txt";
         supportedSuffixes << "log";
         supportedSuffixes << "net";
@@ -571,24 +507,9 @@ namespace Caneda
         supportedSuffixes << "vhd";
         supportedSuffixes << "vhdl";
         supportedSuffixes << "v";
+        supportedSuffixes << "";
 
-        foreach (const QString &suffix, supportedSuffixes) {
-            if (suffix == info.suffix()) {
-                return true;
-            }
-        }
-
-        return false;
-    }
-
-    QStringList TextContext::fileNameFilters() const
-    {
-        QStringList nameFilters;
-        nameFilters << QObject::tr("Spice netlist (*.spc *.sp *.net *.cir)")+" (*.spc *.sp *.net *.cir);;";
-        nameFilters << QObject::tr("HDL source (*.vhdl *.vhd *.v)")+" (*.vhdl *.vhd *.v);;";
-        nameFilters << QObject::tr("Text file (*.txt)")+" (*.txt);;";
-
-        return nameFilters;
+        return supportedSuffixes;
     }
 
     IDocument* TextContext::newDocument()
@@ -603,75 +524,15 @@ namespace Caneda
 
         if (!document->load(errorMessage)) {
             delete document;
-            document = 0;
+            document = nullptr;
         }
 
         return document;
     }
 
-    /*************************************************************************
-     *                           Web Context                                 *
-     *************************************************************************/
-    //! \brief Constructor.
-    WebContext::WebContext(QObject *parent) : IContext(parent)
+    QWidget* TextContext::sideBarWidget()
     {
-        m_sidebarWebBrowser = new SidebarWebBrowser();
-    }
-
-    //! \copydoc MainWindow::instance()
-    WebContext* WebContext::instance()
-    {
-        static WebContext *instance = 0;
-        if (!instance) {
-            instance = new WebContext();
-        }
-        return instance;
-    }
-
-    QWidget* WebContext::sideBarWidget()
-    {
-        return m_sidebarWebBrowser;
-    }
-
-    bool WebContext::canOpen(const QFileInfo& info) const
-    {
-        QStringList supportedSuffixes;
-        supportedSuffixes << "htm";
-        supportedSuffixes << "html";
-
-        foreach (const QString &suffix, supportedSuffixes) {
-            if (suffix == info.suffix()) {
-                return true;
-            }
-        }
-
-        return false;
-    }
-
-    QStringList WebContext::fileNameFilters() const
-    {
-        QStringList nameFilters;
-        nameFilters << QObject::tr("Web page (*.htm *.html)")+" (*.htm *.html);;";
-
-        return nameFilters;
-    }
-
-    IDocument* WebContext::newDocument()
-    {
-        return new WebDocument;
-    }
-
-    IDocument* WebContext::open(const QString& fileName, QString *errorMessage)
-    {
-        WebDocument *document = new WebDocument();
-        document->setFileName(fileName);
-
-        if (!document->load(errorMessage)) {
-            delete document;
-            document = 0;
-        }
-
-        return document;
+        return m_sidebarTextBrowser;
     }
 
 } // namespace Caneda
